spannertools.get_the_only_spanner_attached_to_component
=======================================================

.. autofunction:: abjad.tools.spannertools.get_the_only_spanner_attached_to_component.get_the_only_spanner_attached_to_component
